@@ -11,17 +11,19 @@ from .utils import *
 from .scrollbar import SimpleScrollbar
 
 
-class ScrolledText(tk.Frame):
+class ScrolledText(tk.Text):
     """Scrolled multiline entry good for log output
 
     has both horizontal and vertical scrollbar
 
-    auto-scroll vertically by default, if you move vertical scrollbar it will stop auto  scroll until vertical
+    auto-scroll vertically by default, if you move vertical scrollbar it will stop auto scroll until vertical
     scroll bar moved back to bottom
 
     undo action disabled to save memory
 
-    you can pass extra parameter to Text thru ScrolledText().text.config(**options)
+    basically, this is a Text widget inside an outer Frame with scrolllbars,
+    pack, grid, and place methods for Text will be replaced by outer frame methods
+
     """
 
     def __init__(self, parent, bg='white', fg='black', bd=0, wrap=None, vscroll=True, hscroll=True, autoscroll=True,
@@ -45,7 +47,6 @@ class ScrolledText(tk.Frame):
             hbar_width (int): horizontal scrollbar width
 
         """
-        tk.Frame.__init__(self, parent, bg=bg)
 
         self.bd = bd
         self.bg = bg
@@ -57,9 +58,6 @@ class ScrolledText(tk.Frame):
         self.sbar_bg = sbar_bg
         self.sbar_fg = sbar_fg
 
-        self.rowconfigure(0, weight=1)
-        self.columnconfigure(0, weight=1)
-
         self.var = tk.StringVar()
 
         # wrap mechanism
@@ -68,29 +66,44 @@ class ScrolledText(tk.Frame):
         else:
             wrap = 'none'
 
-        self.text = tk.Text(self, bg=self.bg, fg=self.fg, bd=self.bd, wrap=wrap, undo='false', **kwargs)
-        self.text.grid(sticky='ewns')
+        # create outside frame
+        self.fr = tk.Frame(parent, bg=bg)
+
+        self.fr.rowconfigure(0, weight=1)
+        self.fr.columnconfigure(0, weight=1)
+
+        # initialize super class
+        tk.Text.__init__(self, self.fr, bg=self.bg, fg=self.fg, bd=self.bd, wrap=wrap, undo='false', **kwargs)
+        self.grid(sticky='ewns')
 
         if self.vscroll:
-            self.vbar = SimpleScrollbar(self, orient='vertical', command=self.text.yview, slider_color=self.sbar_fg,
+            self.vbar = SimpleScrollbar(self.fr, orient='vertical', command=self.yview, slider_color=self.sbar_fg,
                                         bg=self.sbar_bg, width=vbar_width)
             self.vbar.grid(row=0, column=1, sticky='ns')
-            self.text.config(yscrollcommand=self.vbar.set)
+            self.config(yscrollcommand=self.vbar.set)
 
         if self.hscroll:
-            self.hbar = SimpleScrollbar(self, orient='horizontal', command=self.text.xview, slider_color=self.sbar_fg,
+            self.hbar = SimpleScrollbar(self.fr, orient='horizontal', command=self.xview, slider_color=self.sbar_fg,
                                         bg=self.sbar_bg, width=hbar_width)
             self.hbar.grid(row=1, column=0, sticky='ew')
-            self.text.config(xscrollcommand=self.hbar.set)
+            self.config(xscrollcommand=self.hbar.set)
 
         # bind mouse wheel to scroll
-        scroll_with_mousewheel(self.text)
+        scroll_with_mousewheel(self)
 
-        # aliases
-        self.delete = self.text.delete
-        self.get = self.text.get
-        self.delete = self.text.delete
-        self.insert = self.text.insert
+        # use outer frame geometry managers
+        self.pack = self.fr.pack
+        self.pack_forget = self.fr.pack_forget
+
+        self.grid = self.fr.grid
+        self.grid_forget = self.fr.grid_forget
+        self.grid_remove = self.fr.grid_remove
+
+        self.place = self.fr.place
+        self.place_forget = self.fr.place_forget
+
+        # for compatibility
+        self.text = self
 
     def set(self, text):
         """replace contents"""
@@ -102,13 +115,13 @@ class ScrolledText(tk.Frame):
                 delta = count - self.max_chars
                 text = text[delta:]
 
-        self.text.insert("1.0", text)
+        self.insert("1.0", text)
 
         self.scrolltobottom()
 
     def clear(self):
         """clear all Text widget contents"""
-        self.text.delete("1.0", tk.END)
+        self.delete("1.0", tk.END)
 
     def append(self, text, text_color=None, text_bg=None):
         """append text with arbitrary colors"""
@@ -116,14 +129,14 @@ class ScrolledText(tk.Frame):
         color_tags = []
 
         if text_color:
-            self.text.tag_configure(text_color, foreground=text_color)
+            self.tag_configure(text_color, foreground=text_color)
             color_tags.append(text_color)
 
         if text_bg:
-            self.text.tag_configure(text_bg, foreground=text_bg)
+            self.tag_configure(text_bg, foreground=text_bg)
             color_tags.append(text_bg)
 
-        self.text.insert(tk.END, text, ','.join(color_tags))
+        self.insert(tk.END, text, ','.join(color_tags))
 
         self.remove_extra_chars()
 
@@ -133,16 +146,15 @@ class ScrolledText(tk.Frame):
         """remove characters from beginning of Text widget if it exceeds max chars"""
         if self.max_chars:
             # get current text characters count
-            # txt = self.text.get()
-            count = len(self.text.get("1.0", tk.END))
+            count = len(self.get("1.0", tk.END))
             if count > self.max_chars:
                 delta = count - self.max_chars
-                self.text.delete("1.0", f"1.0 + {delta} chars")
+                self.delete("1.0", f"1.0 + {delta} chars")
 
     def scrolltobottom(self):
         """scroll to bottom if autoscroll enabled and scrollbar position at the bottom"""
         try:
             if self.autoscroll and self.vbar.get()[1] == 1:
-                self.text.yview_moveto("1.0")
+                self.yview_moveto("1.0")
         except:
             pass 
